@@ -1,5 +1,5 @@
 import functools
-from typing import Coroutine, Dict, List, Union
+from typing import Dict, List, Union
 from .hook_type import HookType
 from hedra.core.graphs.hooks.registry.registry_types.hook import Hook
 from hedra.core.graphs.hooks.registry.registrar import registrar
@@ -10,7 +10,7 @@ def action(
     weight: int=1, 
     order: int=1, 
     metadata: Dict[str, Union[str, int]]={}, 
-    checks: List[Coroutine]=[], 
+    checks: List[str]=[], 
     notify: List[str]=[], 
     listen: List[str]=[]
 ):
