@@ -1,5 +1,5 @@
 import functools
-from typing import Coroutine, Dict, List, Union
+from typing import Dict, List, Union
 from .hook_type import HookType
 from hedra.core.graphs.hooks.registry.registry_types.hook import Hook
 from hedra.core.graphs.hooks.registry.registrar import registrar
@@ -9,7 +9,8 @@ from hedra.core.graphs.hooks.registry.registrar import registrar
 def task(
     weight: int=1, 
     order: int=1, 
-    metadata: Dict[str, Union[str, int]]={}, checks: List[Coroutine]=[],
+    metadata: Dict[str, Union[str, int]]={}, 
+    checks: List[str]=[],
     notify: List[str]=[], 
     listen: List[str]=[]
 ):
