@@ -1,4 +1,4 @@
-from typing import Coroutine, Dict, Any, Callable, Awaitable, Type
+from typing import Coroutine, Dict, Any, Callable, Awaitable, Type, Optional
 from hedra.core.graphs.hooks.hook_types.hook_type import HookType
 from .hook import Hook
 
@@ -11,7 +11,8 @@ class EventHook(Hook):
         shortname: str, 
         call: Callable[..., Awaitable[Any]], 
         *names: str,
-        pre: bool=False
+        pre: bool=False,
+        key: Optional[str]=None
     ) -> None:
         super().__init__(
             name, 
@@ -23,4 +24,5 @@ class EventHook(Hook):
         self.call: Type[self._call] = self._call
         self.names = list(set(names))
         self.pre = pre
+        self.key = key
         self.events: Dict[str, Coroutine] = {}
\ No newline at end of file
