@@ -28,7 +28,6 @@ from hedra.logging import HedraLogger
 from hedra.plugins.types.engine.engine_plugin import EnginePlugin
 from hedra.plugins.types.persona.persona_plugin import PersonaPlugin
 from hedra.plugins.types.plugin_types import PluginType
-from hedra.core.graphs.stages.execute import Execute
 from hedra.core.graphs.stages.base.stage import Stage
 from .exceptions import HookSetupError
 
@@ -106,7 +105,7 @@ class Setup(Stage, Generic[Unpack[T]]):
     def __init__(self) -> None:
         super().__init__()
         self.generation_setup_candidates = 0
-        self.stages: Dict[str, Execute] = {}
+        self.stages: Dict[str, Stage] = {}
         self.accepted_hook_types = [ HookType.SETUP, HookType.EVENT, HookType.CONTEXT ]
         self.persona_types = PersonaTypesMap()
         self.config = Config(
@@ -167,14 +166,17 @@ class Setup(Stage, Generic[Unpack[T]]):
         connection_validation_retries = self.core_config.get('connection_validation_retries', 3)
 
         await self.logger.filesystem.aio['hedra.core'].info(f'{self.metadata_string} - Starting setup')
-
+        
         setup_hooks: List[SetupHook] = self.hooks[HookType.SETUP]
         setup_hook_names = ', '.join([hook.name for hook in setup_hooks])
         
         if len(setup_hooks) > 0:
             await self.logger.filesystem.aio['hedra.core'].info(f'{self.metadata_string} - Runnning Setup hooks for stage - {setup_hook_names}')
         
-        await asyncio.gather(*[hook.call() for hook in setup_hooks])
+        results = await asyncio.gather(*[setup_hook.call(self.context) for setup_hook in setup_hooks])
+        for result in results:
+            self.context = result
+
         execute_stage_id = 1
 
         stages = dict(self.stages)
@@ -324,7 +326,7 @@ class Setup(Stage, Generic[Unpack[T]]):
             for setup_hook in execute_stage.hooks[HookType.SETUP]:
                 await self.logger.filesystem.aio['hedra.core'].info(f'{self.metadata_string} - Executing Setup hook - {setup_hook.name} - for Execute stage - {execute_stage_name}')
 
-                await setup_hook.call()
+                execute_stage.context = await setup_hook.call(self.context)
 
             self.stages[execute_stage_name] = execute_stage
 
@@ -361,7 +363,7 @@ class Setup(Stage, Generic[Unpack[T]]):
         return self.stages
 
     @Internal()
-    async def get_hook(self, execute_stage: Execute, shortname: str, hook_type: str) -> Coroutine:
+    async def get_hook(self, execute_stage: Stage, shortname: str, hook_type: str) -> Coroutine:
         hooks: List[Union[AfterHook, BeforeHook]] = execute_stage.hooks[hook_type]
         for hook in hooks:
             if shortname in hook.names:
@@ -370,7 +372,7 @@ class Setup(Stage, Generic[Unpack[T]]):
                 return hook.call
 
     @Internal()
-    async def get_checks(self, execute_stage: Execute, shortname: str) -> List[Coroutine]:
+    async def get_checks(self, execute_stage: Stage, shortname: str) -> List[Coroutine]:
 
         checks = []
         checks_hooks: List[CheckHook] = execute_stage.hooks[HookType.CHECK]
@@ -383,7 +385,7 @@ class Setup(Stage, Generic[Unpack[T]]):
         return checks
 
     @Internal()
-    async def get_channels(self, execute_stage: Execute) -> None:
+    async def get_channels(self, execute_stage: Stage) -> None:
         listeners: Dict[str, Union[ActionHook, TaskHook]] = {}
         notifiers: Dict[str, Union[ActionHook, TaskHook]] = {}
         channels: Dict[str, ChannelHook] = {channel.shortname: channel for channel in execute_stage.hooks[HookType.CHANNEL]}
@@ -422,4 +424,5 @@ class Setup(Stage, Generic[Unpack[T]]):
         for setup_hook in setup_hooks:
             await self.logger.filesystem.aio['hedra.core'].info(f'{self.metadata_string} - Executing Setup hook - {setup_hook.name}')
 
-            await setup_hook()
\ No newline at end of file
+            await setup_hook()
+            
\ No newline at end of file
