@@ -21,6 +21,7 @@ async def optimize_transition(current_stage: Stage, next_stage: Stage):
     await logger.filesystem.aio['hedra.core'].debug(f'{current_stage.metadata_string} - Executing transition from {current_stage.name} to {next_stage.name}')
 
     execute_stages = current_stage.context.stages.get(StageTypes.EXECUTE).items()
+    optimize_stages = current_stage.context.stages.get(StageTypes.OPTIMIZE).items()
     paths = current_stage.context.paths.get(current_stage.name)
 
     visited = current_stage.context.visited
@@ -29,6 +30,11 @@ async def optimize_transition(current_stage: Stage, next_stage: Stage):
         stage_name: stage for stage_name, stage in execute_stages if stage_name in paths and stage_name not in visited
     }
 
+    optimize_stages_in_path = {}
+    for stage_name, stage in optimize_stages:
+        if stage_name in paths and stage_name != current_stage.name and stage_name not in visited:
+            optimize_stages_in_path[stage_name] = stage.context.paths.get(stage_name)
+
     optimization_candidates = {}
 
     valid_states = [
@@ -37,11 +43,18 @@ async def optimize_transition(current_stage: Stage, next_stage: Stage):
     ]
 
     for stage_name, stage in execute_stages.items():
-        if stage_name in current_stage.context.paths and stage.state in valid_states:
-            stage.state = StageStates.OPTIMIZING
-            optimization_candidates[stage_name] = stage
+        if stage_name in paths and stage.state in valid_states:
+
+            if len(optimize_stages_in_path) > 0:
+                for path in optimize_stages_in_path.values():
+                    if stage_name not in path:
+                        stage.state = StageStates.OPTIMIZING
+                        optimization_candidates[stage_name] = stage
+
+            else:
+                stage.state = StageStates.OPTIMIZING
+                optimization_candidates[stage_name] = stage
 
-    
     next_stage.context = current_stage.context
 
     if len(optimization_candidates) > 0:
@@ -56,6 +69,9 @@ async def optimize_transition(current_stage: Stage, next_stage: Stage):
 
         next_stage.context.optimized_params = optimization_results
 
+        for optimization_candidate in optimization_candidates.values():
+            optimization_candidate.state = StageStates.OPTIMIZED
+
     next_stage.state = StageStates.OPTIMIZED
 
     await logger.spinner.system.debug(f'{current_stage.metadata_string} - Completed transition from {current_stage.name} to {next_stage.name}')
