@@ -2,6 +2,7 @@ import asyncio
 import time
 import uuid
 import psutil
+import math
 from hedra.core.personas.types.default_persona import DefaultPersona
 from hedra.core.engines.client.config import Config
 from hedra.core.personas.types.types import PersonaTypes
@@ -20,7 +21,7 @@ class BatchedPersona(DefaultPersona):
         elapsed = 0
         idx = 0
         action_idx = 0
-        max_pool_size = int(self.batch.size * (psutil.cpu_count(logical=False) * 2)/self.workers)
+        max_pool_size = math.ceil(self.batch.size * (psutil.cpu_count(logical=False) * 2)/self.workers)
 
         start = time.time()
         while elapsed < total_time:
@@ -34,7 +35,7 @@ class BatchedPersona(DefaultPersona):
                 action_idx = (action_idx + 1)%self.actions_count
                 await asyncio.sleep(self.batch.interval)
 
-            if self._hooks[action_idx].session.active%max_pool_size == 0:
+            if self._hooks[action_idx].session.active > max_pool_size:
                     try:
                         max_wait = total_time - elapsed
                         await asyncio.wait_for(
