@@ -7,7 +7,7 @@ from typing import Dict, List, Union
 from concurrent.futures import ThreadPoolExecutor
 from hedra.logging import HedraLogger
 from hedra.tools.helpers import awaitable
-from asyncio import Task
+from asyncio import Task, Future
 from hedra.core.graphs.hooks.hook_types.hook_type import HookType
 from hedra.core.personas.batching.batch import Batch
 from hedra.core.graphs.hooks.registry.registry_types import (
@@ -21,6 +21,11 @@ from hedra.core.personas.types.types import PersonaTypes
 
 async def cancel_pending(pend: Task):
     try:
+        if pend.done():
+            pend.exception()
+
+            return pend
+
         pend.cancel()
         if not pend.cancelled():
             await pend
@@ -30,6 +35,12 @@ async def cancel_pending(pend: Task):
     except asyncio.CancelledError as cancelled_error:
         return cancelled_error
 
+    except asyncio.TimeoutError as timeout_error:
+        return timeout_error
+
+    except asyncio.InvalidStateError as invalid_state:
+        return invalid_state
+
 
 class DefaultPersona:
 
