@@ -1,11 +1,15 @@
+from typing import Any
 from hedra.core.engines.types.websocket import WebsocketResult
 from .http_event import HTTPEvent
 
 
 class WebsocketEvent(HTTPEvent):
 
-    def __init__(self, result: WebsocketResult) -> None:
+    def __init__(self, stage: Any, result: WebsocketResult) -> None:
         super(
             WebsocketEvent,
             self
-        ).__init__(result)
\ No newline at end of file
+        ).__init__(
+            stage,
+            result
+        )
\ No newline at end of file
